@@ -12,7 +12,7 @@ our @ISA = qw(Rose::HTML::Form::Field::Group::OnOff);
 
 our $VERSION = '0.554';
 
-sub _item_class       { shift->object_type_class('radio button') }
+sub _item_class       { shift->object_type_class_loaded('radio button') }
 sub _item_name        { 'radio button' }
 sub _item_name_plural { 'radio buttons' }
 
